BaseTokenMap class

Limited token. Does not provide a refresh token. Commonly obtained via a token refresh.

Implementers

Constructors

BaseTokenMap({String? accessToken, int? expiresIn, String? scope, String? tokenType})
Create new BaseTokenMap.
BaseTokenMap.fromJson(JsonMap json)
Create new BaseTokenMap from a JsonMap.
factory

Properties

accessToken → String?
String to be used in authorization header.
final
expiresIn → int?
Seconds until expiration from request timestamp.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope → String?
Should be 'https://www.googleapis.com/auth/youtube'.
final
tokenType → String?
Should be 'Bearer'.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → JsonMap
Returns this BaseTokenMap instance as JsonMap.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited