YtThumbnailData class

Constructors

YtThumbnailData({required List<YtThumbnail> thumbnails})
YtThumbnailData.fromJson(List<JsonMap> jsonData)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
highRes → YtThumbnail
no setter
lowRes → YtThumbnail
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbnails → List<YtThumbnail>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited