YTMusicBase class

The main class to access the YouTube Music API.

Implemented types
Implementers

Properties

authType AuthType
Get the authentication type.
getter/setter pairoverride-getter
hashCode int
The hash code for this object.
no setterinherited
headers Future<Map<String, String>>
Headers property for requests.
no setteroverride
parser Parser
Get the i18n parser.
getter/setter pairoverride-getter
proxy Uri?
Get the proxy configuration.
getter/setter pairoverride-getter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

asMobile<T>(Future<T> callback()) Future<T>
Set client temporary as YouTube Music Mobile app for sending request.
override
checkAuth() → void
Checks if the user has provided authorization credentials.
override
close({bool force = true}) → void
Closes the session.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendGetRequest(String url, {JsonMap? params, bool useBaseHeaders = false}) Future<Response>
Send a GET request to YouTube Music.
override
sendRequest(String endpoint, JsonMap body, {String additionalParams = ''}) Future<JsonMap>
Send a POST request to YouTube Music.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited